#
# spec file for package clementine
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define rev bbda59a5f347a75bbecde0b1928e03942e367850

%bcond_without git

%if 0%{?suse_version} > 1500
%bcond_without manpage
%else
%bcond_with manpage
%endif
%bcond_without qt5
%define gname Clementine

Name:           clementine
Version:        1.4.0~rc2
Release:        5.9
Summary:        A music player inspired by Amarok 1.4
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Sound/Players
URL:            https://clementine-player.org/
%if %{without git}
#Source:         https://github.com/clementine-player/%%{gname}/archive/%%{version}.tar.gz#/%%{name}-%%{version}.tar.gz
%else
Source0:        https://github.com/clementine-player/Clementine/archive/%{rev}.tar.gz#/%{name}-%{version}.tar.gz
%endif
# PATCH-FEATURE-UPSTREAM uudisks2-support-for-devicemanager.patch
Patch1:         clementine-udisks-headers.patch
# Patch fix factory build, add -fPIC to moodbar build
Patch2:         clementine-moodbar-fpic.patch
# PATCH-FEATURE-OPENSUSE
Patch6:         use_system_qxtglobalshortcut.patch
# Use C++17
Patch3:         clementine-cpp17.patch
# Fix build with protobuf 22 and higher
Patch4:         clementine-protobuf.patch
# Fix build with TagLib 2
Patch5:         clementine-taglib2.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  freeglut-devel
BuildRequires:  gcc-c++
BuildRequires:  gettext-tools
BuildRequires:  help2man
BuildRequires:  hicolor-icon-theme
BuildRequires:  libboost_headers-devel
BuildRequires:  update-desktop-files
%if %{with qt5}
#BuildRequires:  pkgconfig(qca2-qt5)
BuildRequires:  libQt5Gui-private-headers-devel
BuildRequires:  liblastfm-qt5-devel
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core) >= 5.6
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(libmygpo-qt5)
BuildRequires:  pkgconfig(qxtglobalshortcut)
#BuildRequires:  pkgconfig(QxtCore-qt5)
%else
BuildRequires:  liblastfm-devel
BuildRequires:  libqxt-devel
BuildRequires:  pkgconfig(QJson)
BuildRequires:  pkgconfig(QtCore)
BuildRequires:  pkgconfig(QtGui)
BuildRequires:  pkgconfig(QtSql)
%endif
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(cryptopp)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-app-1.0)
BuildRequires:  pkgconfig(gstreamer-audio-1.0)
BuildRequires:  pkgconfig(gstreamer-base-1.0)
BuildRequires:  pkgconfig(gstreamer-tag-1.0)
BuildRequires:  pkgconfig(libcdio)
BuildRequires:  pkgconfig(libchromaprint)
BuildRequires:  pkgconfig(libgpod-1.0)
BuildRequires:  pkgconfig(libmtp)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libprojectM)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libsparsehash)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(taglib) >= 2
%if %{without qt5}
Recommends:     sni-qt
%else
Recommends:     projectM-data
%endif
# clementine-kde was last used in openSUSE 12.2.
# plasma_runner was dropped in Clementine 1.1.0.
Provides:       %{name}-kde = %{version}
Obsoletes:      %{name}-kde < %{version}

%description
Clementine is a music player and library organiser.
It is inspired by Amarok 1.4, focusing on a fast and easy-to-use
interface for searching and playing your music.

Features:

 * Search and play your local music library.
 * Play audio CDs.
 * Edit tags on audio files and organise your music.
 * Native desktop notifications.
 * Tabbed playlists, import and export M3U, XSPF, PLS and ASX.
 * Create smart playlists and dynamic playlists.
 * Download missing album cover art from Last.fm, MusicBrainz and Discogs.
 * Lyrics and artist biographies and photos.
 * Copy music to your iPod, iPhone, MTP or mass-storage USB player.
 * Queue manager.
 * Search and play songs you've uploaded to Box, Dropbox, Google Drive, and OneDrive
 * Listen to internet radio from Spotify, Grooveshark, SomaFM, Magnatune, Jamendo,
 SKY.fm, Digitally Imported, JAZZRADIO.com, Icecast and Subsonic servers.

%prep
%if %{without git}
%setup -q -n %{gname}-%{version}
%else
%setup -q -n %{gname}-%{rev}
%endif
%autopatch -p1

# NOTE: Build using system versions of libraries.
rm -rvf 3rdparty/taglib
rm -rvf 3rdparty/SPMediaKeyTap

%build
%ifarch %{arm} aarch64
%define _lto_cflags %{nil}
%endif
export CFLAGS="%{optflags} -fno-strict-aliasing -ggdb"
export CXXFLAGS="$CFLAGS"
%cmake \
  -DBUILD_WERROR=OFF                   \
  -DUSE_SYSTEM_QTSINGLEAPPLICATION=OFF \
  -DUSE_SYSTEM_PROJECTM=ON             \
  -DBUNDLE_PROJECTM_PRESETS=OFF        \
%if %{with qt5}
  -DUSE_SYSTEM_QXT=ON                 \
%else
  -DUSE_SYSTEM_QXT=ON                  \
%endif
  -DENABLE_MOODBAR=ON                  \
  -DENABLE_DBUS=ON
make %{?_smp_mflags}

%install
%cmake_install

%if %{with manpage}
# Generate a man page with help2man.
mkdir -p %{buildroot}%{_mandir}/man1/
pushd %{buildroot}%{_mandir}/man1/
cp -f %{buildroot}%{_bindir}/%{name} ./
help2man --version-string="%{version}" -N -o %{name}.1 ./%{name}
rm -f %{name}
popd
%endif

%if 0%{?suse_version} < 1500
%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files
%defattr(-,root,root)
%doc Changelog README.md
%license COPYING
%{_bindir}/clementine*
%{_datadir}/applications/org.clementine_player.Clementine.desktop
%{_datadir}/icons/hicolor/*/apps/org.clementine_player.Clementine*
%if %{with manpage}
%{_mandir}/man1/%{name}.1%{?ext_man}
%endif
%if %{with qt5}
%{_datadir}/metainfo/
%{_datadir}/kservices5/
%else
%dir %{_datadir}/appdata/
%{_datadir}/appdata/clementine.appdata.xml
%dir %{_datadir}/kde4/
%dir %{_datadir}/kde4/services/
%{_datadir}/kde4/services/clementine-*.protocol
%endif

%changelog
* Sun Mar 17 2024 Jonas Kvinge <jonaski@opensuse.org>
- Add clementine-cpp17.patch:
  * Fixes build with TagLib and Protobuf now requiring C++17.
- Add clementine-protobuf.patch:
  * Fixes build with protobuf 22 and higher.
- Add clementine-taglib2.patch:
  * Fixes build with TagLib 2.
- Removed clementine-ix86-build-fix.patch and
  clementine-cpp17-force.patch.
* Thu Mar  7 2024 Max Lin <mlin@suse.com>
- Fix build error with protobuf 25 in Leap 15.6
  * Apply clementine-cpp17-force.patch and clementine-ix86-build-fix.patch
    to Leap 15.6 build
* Wed Feb 28 2024 Dave Plater <davejplater@gmail.com>
- Allow use of internal taglib until taglib2 build issue is solved
  see https://github.com/clementine-player/Clementine/issues/7313
* Mon Jul 10 2023 Dave Plater <davejplater@gmail.com>
- Fix build on tumbleweed with clementine-cpp17-force.patch by
  forcing -std=c++17 on protobuf-using subdirectories.
- Add clementine-ix86-build-fix.patch to fix ix86 build
  (missing protobuf link libs).
* Tue Aug  9 2022 Dave Plater <davejplater@gmail.com>
- Update to version 1.4.0~rc2
- Remove unneeded patch clementine-hidden-systray-icon.patch
- Many bug fixes and new features since the last git snapshot
* Fri Jun 11 2021 Jiri Slaby <jslaby@suse.cz>
- update to 1.3.99.20210609
  * For upstream changes go to:
    https://github.com/clementine-player/Clementine/compare/354f6a23e0ce...612767c87822
* Thu Apr  8 2021 Dave Plater <davejplater@gmail.com>
- Update to git snapshot 1.3.99.20210304 to fix build against the
  new taglib.
- For upstream changes go to:
  https://github.com/clementine-player/Clementine/compare/1.4.0rc1-343-gb49afcc5b...1.4.0rc1-548-g354f6a23e
* Mon Dec 14 2020 Antonio Larrosa <alarrosa@suse.com>
- Clementine only needs taglib newer than 1.11.1 so it contains
  a fix for a bug which we have patched in SLE/Leap 15 (check
  CMakeLists.txt and boo#1179817 for more information). So we
  can allow taglib 1.11.1 too.
* Wed Sep 30 2020 Jiri Slaby <jslaby@suse.cz>
- update to 1.3.99 (tagged as 1.4.0rc1-343-gb49afcc5b)
  * a lot of features and fixes, see the changes:
    https://github.com/clementine-player/Clementine/compare/eeb9f7e30311...b49afcc5b731
- remove 0001-Adds-missing-QPainterPath-include.patch
  It's upstream now.
* Thu Jul  9 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add _constraints for PowerPC to avoid "No space left" build error
* Tue Jun  2 2020 Dave Plater <davejplater@gmail.com>
- Fix factory build with patch from git:
  0001-Adds-missing-QPainterPath-include.patch
- Update to tag 1.3.92
* Mon Dec 30 2019 Dave Plater <davejplater@gmail.com>
- Update to release version 1.3.9, first release since 2016.
- Upstream changes:
  * Fix gpodder sync memory leaks in success cases.
  * Fix resuming playback position on startup
  * Remove obsolete forced setting of XDG_CONFIG_HOME
  * Fix multiple triggers of shortcut actions
  * Fix a few more gst plugins
  * Use AWS mirror for eoan & disco too
  * Fix edit tag dialog
  * Change remaining group by defaults to album artist
  * Fix updating song count
  * Add check for valid birthTime()
  * Remove watch for removed subdirectories
  * Remove qt4 dependency
* Sun Nov 10 2019 Dave Plater <davejplater@gmail.com>
- Update to git snapshot 1.3.1+git20191110
- Upstream changes:
  * Replace QString::null with QString()
  * qt5 branch is now master.
* Sun Oct 13 2019 Dave Plater <davejplater@gmail.com>
- Update to git snapshot 1.3.1+git20191004
- Removed incorporated patches:
  0001-Fix-memory-leaks-in-database.patch
  0001-Fix-memory-leaks-6376.patch and
  delete_the_allocated_memory_in_respective_destructors.patch which
  fixes boo#1141444
- Upstream changes:
  fancytabwidget.cpp: reuse QSettings object
  fancytabwidget.cpp: prefer QString to std::string
  Periodically save current playlist tab
  Periodically save settings
* Sat Aug  3 2019 Dave Plater <davejplater@gmail.com>
- Added patch from git 0001-Fix-memory-leaks-6376.patch, this patch
  replaces the tagreader section in:
  delete_the_allocated_memory_in_respective_destructors.patch.
* Fri Jul 26 2019 Dave Plater <davejplater@gmail.com>
- Update to qt5 branch snapshot 1.3.1+git20190724
- Removed incorporated patches:
  0001-Improved-support-for-APEv2-tags.-6280.patch
  0001-Prevent-UI-hang-during-device-scan.-6291.patch
  0001-Fix-thread-safety-issues-when-initially-loading-devi.patch
  0001-Handle-case-where-a-lister-adds-a-device-before-load.patch
  0001-Fix-MoodbarPipeline-crash-on-gstreamer-error.patch
  0001-Fix-potential-use-of-streamer-element-after-deletion.patch
  0001-Free-decoder-bin-if-error-occurs-during-setup.patch
  0001-Fix-several-gstreamer-object-leaks.patch
  0001-Add-error-handling-path-for-async-song-loading.patch
  0001-Fixes-for-APE-filetype.patch
  0001-Simplify-some-statements.patch
  0001-Set-non-zero-minimum-for-fade-times.patch
  0001-Fix-a-number-of-potential-zero-value-field-values.patch
  0001-Introduce-limit-for-number-of-tag-client-processes.patch
  0001-Fix-crash-in-messagereply-6372.patch
- Refreshed old patches
- Added patch from git:
  0001-Fix-memory-leaks-in-database.patch
* Thu Jul 25 2019 Dave Plater <davejplater@gmail.com>
- Recommend projectM-data for visualizations.
* Tue Jul 23 2019 Dave Plater <davejplater@gmail.com>
- Updated memory leak patch (boo#114144):
  delete_the_allocated_memory_in_respective_destructors.patch
- Fixed boo#1137785 with upstream patch from git:
  0001-Fix-crash-in-messagereply-6372.patch
- Added patch from git:
  0001-Introduce-limit-for-number-of-tag-client-processes.patch
* Mon Jul 15 2019 Dave Plater <davejplater@gmail.com>
- Update to qt5 branch snapshot 1.3.1+git20190713.
- Add patch for memory leaks from Jiri Slaby via boo#114144 :
  delete_the_allocated_memory_in_respective_destructors.patch
- Upstream changes:
  * Fix blank window when restoring from systray (#6351)
* Fri Jul 12 2019 Dave Plater <davejplater@gmail.com>
- Update to qt5 branch snapshot 1.3.1+git20190609.
- Verify boo#1103041 is fixed with:
  0001-Fix-MoodbarPipeline-crash-on-gstreamer-error.patch
- Remove incorporated patch:
  0001-Fix-gst_buffer_unref-assertion-in-chromaprinter.patch
* Wed Jun  5 2019 Dave Plater <davejplater@gmail.com>
- Added patch from git 96a7e18a8d2be8d9f3223a6a6c81fbaac1179869 to
  fix various Tag zero value issues:
  0001-Fix-a-number-of-potential-zero-value-field-values.patch
* Fri May 24 2019 plater <davejplater@gmail.com>
- Build with -fsanitize=address.
* Wed May 22 2019 plater <davejplater@gmail.com>
- Update to qt5 branch snapshot 1.3.1+git20190423.
- Added cherrypicked patches to bring qt5 branch to master's state:
  0001-Fix-gst_buffer_unref-assertion-in-chromaprinter.patch
  0001-Add-error-handling-path-for-async-song-loading.patch
  0001-Fixes-for-APE-filetype.patch
  0001-Simplify-some-statements.patch and
  0001-Set-non-zero-minimum-for-fade-times.patch.
- Upstream changes:
  * Revert "Blacklist all NVidia drivers"
  * setFirstSectionMovable() in playlistview.cpp
* Wed Mar 27 2019 plater <davejplater@gmail.com>
- Added use_system_qxtglobalshortcut.patch to improve kde
  integration.
  _ Added cherrypicked patches to bring qt5 branch to master's state:
  0001-Improved-support-for-APEv2-tags.-6280.patch,
  0001-Prevent-UI-hang-during-device-scan.-6291.patch,
  0001-Fix-thread-safety-issues-when-initially-loading-devi.patch,
  0001-Handle-case-where-a-lister-adds-a-device-before-load.patch,
  0001-Fix-MoodbarPipeline-crash-on-gstreamer-error.patch,
  0001-Fix-potential-use-of-streamer-element-after-deletion.patch,
  0001-Free-decoder-bin-if-error-occurs-during-setup.patch and
  0001-Fix-several-gstreamer-object-leaks.patch.
* Sat Mar 16 2019 plater <davejplater@gmail.com>
- Update to git qt5 snapshot version 1.3.1+git20190213.
- Removed incorporated patches: clementine-gcc7fix.patch and
  clementine-gsd-dbus-shortcuts.patch.
* Sun Jan 13 2019 Jonas Kvinge <jonas@jkvinge.net>
- Update summary and description
- Remove clementine-lastscope-size.patch, this bug is already fixed
  upstream by me, and this patch does not apply cleanly.
- Add clementine-gsd-dbus-shortcuts.patch to fix global shortcuts
  using Gnome (GSD) D-Bus backend
- Add needed alsa dependency
- Remove unneeded libechonest dependency
- Replace non-existent USE_BUILTIN_TAGLIB with USE_SYSTEM_TAGLIB
  option
- Remove unneeded taglib and SPMediaKeyTap directory
* Wed Dec  5 2018 davejplater@gmail.com
- Update to git qt5 snapshot version 1.3.1+git20181203, it fixes
  build with libcryptopp7.
- Clementine now uses qt5 to run.
- Added clementine-hidden-systray-icon.patch, systray icon is
  hidden at start up on some kf5 systems.
* Sun Dec  2 2018 davejplater@gmail.com
- Update to git qt5 snapshot version 1.3.1+git20181201
* Sat Nov  3 2018 davejplater@gmail.com
- Update to git qt5 snapshot version 1.3.1+git20181022
- Removed incorporated patches: clementine-fix-sqlite.patch,
  clementine-1.3.1-support-chromaprint-1.4.patch,
  clementine-1.3.1-fix-library-clicks.patch, 6103.patch and
  udisks2-support-for-devicemanager.patch.
- Added patches from Fedora: clementine-lastscope-size.patch and
  clementine-udisks-headers.patch.
- Disable man page build for Leap:15 as it causes build failures.
* Mon Oct 29 2018 Jan Engelhardt <jengelh@inai.de>
- Trim bias and openSUSE-irrelevant wording from description.
* Sun Oct 28 2018 Andrey Karepin <egdfree@opensuse.org>
- added patch 6103.patch with fix track change hang
* Sat Dec  9 2017 fabian@ritter-vogt.de
- Do not build against Qt WebKit 4
* Tue Jul 25 2017 tchvatal@suse.com
- Do not recommend fluendo as mp3 is enabled out of the box now in gst
- Remove if0 conditional that is never triggered
* Tue Jul 25 2017 aloisio@gmx.com
- Added clementine-1.3.1-support-chromaprint-1.4.patch to fix
  build
* Mon Apr  3 2017 davejplater@gmail.com
- Fix gcc 7 build with clementine-gcc7fix.patch
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Mon Jul 11 2016 davejplater@gmail.com
- Fix factory build for x86_64 with clementine-moodbar-fpic.patch
* Fri Jun 24 2016 sor.alexei@meowr.ru
- Add clementine-1.3.1-fix-library-clicks.patch: fix a misbehaviour
  while clicking on tree items, from upstream commit b85d09c by
  Ivan Leontiev.
* Sun Jun 19 2016 hrvoje.senjan@gmail.com
- Added udisks2-support-for-devicemanager.patch from upstream
* Wed Apr 20 2016 sor.alexei@meowr.ru
- Update to version 1.3.1:
  * Fix ratings being deleted when upgrading from older versions.
* Sun Apr 17 2016 olaf@aepfle.de
- Remove unused ffmpeg-devel
* Sun Apr 17 2016 sor.alexei@meowr.ru
- Add clementine-fix-sqlite.patch (fix startup with default
  SQLite 3.12+) from
  https://github.com/clementine-player/Clementine/issues/5297#issuecomment-196211148
- Add -fno-strict-aliasing to CXXFLAGS (strict-aliasing-punning).
* Sat Apr 16 2016 sor.alexei@meowr.ru
- Update to version 1.3.0:
  * VK.com support.
  * Seafile support (server >= 4.4.1).
  * Add Ampache compatibility (through Subsonic service).
  * Add new analyser "Rainbow Dash".
  * Answer to the ultimate question of life, the universe and
    everything.
  * Add "Psychedelic Colour" mode to all analysers.
  * Add left click to fullsize cover on playing widget.
  * Add m4b support for non-drm files.
  * Ignore English articles for library sorting.
  * Improve the organise dialog.
  * Add an option to warn before closing a playlist tab.
  * Add an option to disable the pause notification.
  * Add options to hide some internet services.
  * Add an option to disable inline song metadata editing.
  * Add "details below" and "no details" now playing widget
    options.
  * Add "no song details" now playing widget option.
  * Add icons to the extras menu.
  * Add a source icon for CD tracks.
  * Allow user to remove directories in the Files tab.
  * Add ability to remove unavailable items from playlist.
  * Add a button to the transcode dialog to add all files in a
    directory.
  * Make it impossible to collapse either side of the MainWindow
    splitter.
  * Add menu items for updating and doing a full rescan of
    Google Drive.
  * Increase Soundcloud cover image size.
  * Add the ability to pause Spotify tracks.
  * Add the ability to add or remove a Spotify track to a Spotify
    playlist through context menu.
  * Add Spotify tracks to Spotify playlists by drag and drop.
  * Add ability to get a link to share Spotify playlists and songs.
  * Improve handling of Spotify Top Tracks and compilations.
  * Add playlist actions to Spotify songs.
  * Add ability to automatically set podcast as listened after
    successfully sending it to a device.
  * Add ability to order podcasts by age.
  * Allow user to download multiple podcasts at the same time.
  * Add ability to cancel podcast downloads in progress.
  * Allow user to hide listened podcast episodes.
  * Huge improvement of the speed at startup.
  * Improve performance of mass rating changes.
  * Improve ripping performance.
  * Persistent cache for pixmaps. Huge improvement of the
    performance when scrolling the library for example.
  * Add AppData file for Clementine (for GNOME and KDE Software
    Centres).
  * Add iPod-like behaviour to previous button.
  * Add HipHop and Kuduro equalisers.
  * Remember current playlist between restarts.
  * IDv3 tag lyrics support.
  * Scroll to last played track when switching playlists.
  * Add stop after each song repeat mode.
  * Sort discs numerically when using Group by disc.
  * Add ability for sort by group and performer in the library view.
  * Parse the year of a disc from musicbrainz.
  * Add track intro mode.
  * Add ability to add a search term with tab and space in the
    smart playlist window.
  * Add love/ban (Last.fm) global shortcuts.
  * Add support for "original year" tags.
  * Send album artist to Last.fm with liblastfm >= 1.0.0.
  * Add sample rate selection.
  * Add option to change the time step when seeking using the
    keyboard.
  * Playlist sort by album considers disc and track numbers.
  * Add options for double clicking song in the playlist.
  * Volume slider handles glow effect using system theme.
  * Library view sort line themable.
  * Show track durations in the CD ripper dialog.
  * Add ability to read REM DISC tag from Cue sheet.
  * Add ability to lock/unlock rating edit status.
  * Add the support of trackNum elements in XSPF.
  * Add "Smart Playlists" for Subsonic.
  * Add lyrics from AZLyrics.
  * Add lyrics from bollywoodlyrics.com.
  * Add lyrics from hindilyrics.net.
  * Add lyrics from lololyrics.com.
  * Add lyrics from Musixmatch.
  * Add lyrics from Tekstowo.pl.
  * Fix crash when click on a SoundCloud entry in internet tab.
  * Fix crash when marking podcast as listened.
  * Fix crash after pressing OK in the device properties window.
  * Fix stop after track which doesn't remove now playing.
  * Fix play bleeding into next track after auto stop.
  * Fix analyser framerate when mouseover play scrubber.
  * Fix issues with buffers sent to analyser.
  * Fix block analyser framerate.
  * Fix divide-by-zero possibility with small buffers at end of
    track.
  * Fix divide-by-zero possibility in moodbar.
  * Fix oversized album cover art.
  * Clean cover art from /tmp.
  * Fix the rendering of the little numbers in the boxes on queued
    items in the playlist.
  * Fix parsing of MusicBrainz data for discid.
  * Fix random artifacting on nyanalyser on startup.
  * Fix podcasts length issues (which caused issues with seeking
    for example).
  * Fix too small equaliser window size.
  * Fix labels which don't inherit system text colours in the edit
    tag dialog.
  * Fix the mess of the queue manager after playlist re-sort.
  * Fix for queue ordering issue in the playlist view when using
    Ctrl+D to dequeue a track.
  * Fix detection of parent-relative paths in playlist saving.
  * Fix path seperators issue when reading playlists.
  * Fix m3u parser issue when an artist's name has a hyphen.
  * Fix bug with percents when fetch the Jamendo catalogue.
  * Fix a little dropout when transition to next track.
  * Fix broken RockRadio.com for premium users.
  * Fix Subsonic login with + characters in the password.
  * Fix accents issue in when save playlist in xspf format.
  * Fix issues with some songs length thanks to Taglib. People with
    Taglib installed on their system will have to wait a new
    release of Taglib.
  * Fix moodbars not generating correctly.
  * Fix socket leak in moodbar.
  * Fix memory leak in tagreader.
  * Fix crash when trying to fingerprint but missing a plugin.
  * Fix infinite scan with Subsonic when the library is empty.
  * Fix performer tag for mpeg.
  * Fix parsing issues with "innovative" datetime formats.
  * Fix playback breaks in Spotify.
  * Fix memory leaks.
  * Fix crash when stopping song that is fading after pausing.
  * Fix crash when trying to download a track but there is no
    current one playing.
  * Fix default spinner gif image which shows white pixels around
    the image.
  * Fix setting album artist tag for FLAC files if it already
    exists.
  * Fix crash when Clementine lists the albums on Ampache.
  * Fix Last.fm scrobbling after seek.
  * Fix metadata not processed properly for some streams (Akamai).
  * Fix save state when the song was paused.
  * Fix some issues in Boom and Turbine analysers.
  * Fix song continuously rewinding when seeking using keyboard
    arrow keys.
  * Fix OSD re-posistioning which doesn't work on multiple monitors.
  * Fix Sonogram state while paused.
  * Fix crash when changing 'group by' while album covers are still
    loading.
  * Fix loss of valid data from an mp3 file when using the metadata
    editor.
  * Fix track slider twitching.
  * Fix Di.fm stations stuck when try to play them without Internet.
  * Make mood files hidden in NTFS.
  * Fix time labels blinking when playing streams without known
    duration.
  * Fix tag fetcher which applies incorrect tags for songs without
    any results.
  * Fix Clementine getting stuck when transitioning from a local
    track to a Spotify track with crossfade disabled.
  * Fix previous track when playing a dynamic random mix.
  * Fix fullscreen album covers for monitors in portrait mode.
  * Don't scale down star icons by 1 pixel.
  * Remove Ubuntu One support.
  * Remove Discogs support.
  * Remove GrooveShark support.
  * Remove Radio GFM support.
  * Update to GStreamer 1.x.
  * Don't compile vreen with link-time optimisations.
  * Use the system's sha2 library if it's available.
  * Remove libindicate-qt.
  * Remove internal copy of libechonest and add it as dependency.
  * Use libcrypto++ instead of QCA.
  * Update TagLib to 1.10.0.
  * Follow freedesktop.org specifications for icons.
  * Add a 128x128 version of the Clementine icon.
  * Remove internal copy of chromaprint and add it as
    dependency.
  * Don't depend on libplist or usbmuxd.
- Use built-in libmygpo-qt: Clementine needs currently
  not released libmygpo-qt 1.0.9+.
- Add sni-qt to recommendations.
- Remove
  clementine-1.2.2-dont-use-hacks-but-proper-sintax-for-non-wrapping-in-namespace.patch:
  merged upstream.
- Some spec cleanup.
* Sat Mar  5 2016 davejplater@gmail.com
- Added recommends for gstreamer-0_10-plugins--fluendo_mp3 to fix
  missing plugins message. See boo#904155
* Sun Nov  2 2014 BM-2cTD873dxoyND9nkERkefY9xMV8Vy2ga2w@bitmessage.ch
- check for 1230 in spec-file and do not use cmake-rpm-macro for 12.3
* Wed Oct 15 2014 seanpwatson@live.com
- Update to 1.2.3
  * Fix compilation with GCC 4.9
  * Fix poor search performance with sqlite 3.8.
- Dropped clementine-1.2.2-add-missing-header.patch:Fixed upstream
- Dropped clementine-1.2.2-add-missing-include.patch:Fixed upstream
* Fri Mar 28 2014 hrvoje.senjan@gmail.com
- Added clementine-1.2.2-dont-use-hacks-but-proper-sintax-for-non-wrapping-in-namespace.patch,
  fixes build with newer/stricter CMake
- As per patch, re-enable DBus
- Drop udisks BuildRequires, not needed
* Thu Mar 27 2014 tchvatal@suse.com
- Version bump to 1.2.2:
  * upstream moved homepage
  * android remote support
  * Rename SkyDrive to OneDrive.
  * Don't include the user's IP address in the log (from the network remote
    settings dialog).
  * (Debian) Fix a bug with HTTPS logins to all cloud storage providers.
  * (Mac OS X) Fix a bug in the workaround for a weird font issue on 10.9.
  * (Mac OS X) Fix rendering of source icons on retina displays.
  * (Android Remote) Don't advertise songs that aren't available.
  * (Android Remote) Fix playing songs with special characters in filenames.
- Cleanup with spec-cleaner
- Remove support for < 12.3 codepaths
- Remove unused patches:
  * clementine-1.1.1-fixboostparseerror.patch
  * clementine-desktop-fix.patch
- Add patches for build from upstream:
  * clementine-1.2.2-add-missing-header.patch
  * clementine-1.2.2-add-missing-include.patch
- Disable building with Werror, it is always bad idea to do so.
- Add dependency over udisks as it is used by build
- Use system projectM again as it seems to build fine.
- Bug workaround: disable DBUS interface as it fails to build for
  some non-aparent reason.
* Thu Nov 28 2013 fisiu@opensuse.org
- Update to 1.2.1:
  * Fix library download in the network remote.
  * Fix removing songs from playlist in the network remote.
  * Fix login failures with box.com.
  * Fix a typo that would prevent the Spotify downloader button from
    ever being shown.
* Thu Oct 17 2013 fisiu@opensuse.org
- Update to 1.2.0:
  * Add support for indexing and playing music from Box, Dropbox, Skydrive,
    and Ubuntu One.
  * Add support for Subsonic.
  * Remote control support for Android.
  * Add a Playlist tab to the sidebar.  Starred playlists are saved in here
    when their tabs are closed.
  * Add configurable blur & opacity to album art when used as a playlist
    background.
  * Support Opus where available.
  * Support .mka and .oga file extensions.
  * Parsing support for WPL playlists.
  * Sort providers by user preference.
  * Add year and bitrate to MPRIS2 messages.
  * Add "not equals" operator to fields in the smart playlist wizard.
  * Add an option to write ratings, play count and scores to files.
  * Add options to show the rating and score on the OSD.
  * Add support for POPM tags.
  * Add support for FMPS tags in Ogg, FLAC, MP4 and ASF files.
  * Compile the bundled Taglib with ASF, MP4 and Opus support.
  * Make it possible to cancel cover searches.
  * Add an option to resume playback on startup.
  * Add support for Performer and Grouping tags.
  * Add Radio GFM.
  * Add an Apply button to the settings dialog.
  * Make it possible to mark all episodes of a podcast as new/listened.
  * Add an option for fading in/out on pause/unpause.
  * Add stereo balance slider to the equalizer.
  * Add a --restart-or-previous commandline flag.
  * Allow files to be transcoded directly from the playlist.
  * Export downloaded album covers
  * Removed iDevice support - it doesn't work well with modern devices and
    libgpod isn't being updated to support them.
  * Many bugfixes
- Drop sites.js and ultimate_providers.xml: fixed upstream.
- Drop clementine-nowerror.patch: fixes upstream.
- Drop Add-a-setting-for-disabling-moodbar-generation.patch: fixed upstream.
- Drop clementine-libimobiledevice-fix.patch: iDevice support dropped upstream
* Wed Oct  2 2013 speilicke@suse.com
- Only apply clementine-libimobiledevice-fix.patch on 13.1 or later
  to fix build
* Wed Jul 24 2013 coolo@suse.com
- port usage of libimobiledevice to new version (upstream killed
  the feature in git though)
* Thu May  2 2013 jslaby@suse.com
- Add-a-setting-for-disabling-moodbar-generation.patch: Add a setting
  for disabling moodbar generation. Fixes issue #3161 (bnc#818127)
* Sun Apr 28 2013 davejplater@gmail.com
- Fixed bnc#815434 with "-DCMAKE_BUILD_TYPE:STRING=Release" flag.
- Fixed factory build with clementine-1.1.1-fixboostparseerror.patch
  see also QTBUG-22829
* Thu Apr  4 2013 davejplater@gmail.com
- Fixed factory build with clementine-nowerror.patch
* Wed Feb  6 2013 davejplater@gmail.com
- Fix 12.1 build by requiring libproto-devel as well as
  libproto-lite6
- Require libtag1 >= 1.8 see bnc#779411
* Wed Jan  2 2013 fisiu@opensuse.org
- Fix polish lyrics parser.
  http://code.google.com/p/clementine-player/issues/detail?id=3303
* Thu Dec  6 2012 saschpe@suse.de
- Update to version 1.1.1:
  + Bundle Taglib 1.8 on older distros to enable Google Drive support
    in Clementine.
- Properly provide/obsolete clementine-kde
- Drop support for openSUSE-11.4
- Use the same desktop file categories as Amarok
* Mon Nov  5 2012 fisiu@opensuse.org
- Update to version 1.1.0:
  + Podcast support with integration with gpodder.net.
  + Add support for indexing and playing music from Google Drive.
  + Add Soundcloud support.
  + Add jazzradio.com support.
  + Moodbar support.
  + Many other changes and a lot of bug fixes, details available
    in Changelog file.
- Subpackage clementine-kde is obsolete: dropped plasma runner.
* Thu Oct  4 2012 saschpe@suse.de
- Add build requirement on freeglut-devel (GL/glu.h include missing)
* Mon Sep 17 2012 davejplater@gmail.com
- Update to 17/09/2012 git head to fix bnc#779411
- For upstream changes see :
  /usr/share/doc/packages/clementine/Changelog
* Thu May  3 2012 davejplater@gmail.com
- Added libprotobuf-lite6 to 12.1 build to fix builds for Tumbleweed.
* Mon Apr 30 2012 davejplater@gmail.com
- Update to 26/04/2012 git head to fix factory build
- Upstream added clementine-tagreader
* Sun Apr  8 2012 davejplater@gmail.com
- Fixed libcdio, changed build dependency to pkgconfig(libcdio)
* Sun Feb  5 2012 seiler@b1-systems.de
- modified source patch to an dynamical download link
- resubmitted package with gzip compressed sources instead of bzip2
* Thu Feb  2 2012 seiler@b1-systems.de
- changed fftw devel dependency to pkgconfig dependency
* Wed Feb  1 2012 seiler@b1-systems.de
- updadet to version 1.0.1
- added another dependency
- modified file section to /usr/lib/ instead of /usr/lib64
* Tue Jan 24 2012 saschpe@suse.de
- Use BuildRequires: libcdio-devel instead of pkgconfig() to avoid
  "Have choice..."
* Mon Jan  2 2012 fisiu@opensuse.org
- Build with plasma search support, add -kde subpackage.
* Sun Jan  1 2012 fisiu@opensuse.org
- Use pkgconfig() instead -devel in BuildRequires.
* Fri Dec 30 2011 fisiu@opensuse.org
- Update to 1.0.0:
  + Add audio CD support.
  + Add Amazon as an alternate provider for album cover art.
  + Add a global search feature.
  + Add Spotify support.
  + Add Grooveshark support.
  + Add Digitally Imported (di.fm) and Sky.fm radio stations.
  + Many other changes and a lot of bug fixes, details available
    in Changelog file.
* Wed Sep  7 2011 davejplater@gmail.com
- Merged KDE:Extra build with mmaps build and added libnotify and
  libQtWebKit to the build for extra functionality.
* Wed Aug 17 2011 saschpe@suse.de
- Added BuildRequires:
  * gstreamer-0_10-plugins-base-devel to fix build on openSUSE:12.1
  * libcdio-devel to enable Audio CD support
* Wed Aug 17 2011 saschpe@suse.de
- Update to 0.7.3:
  * Translation updates
  * Drag'n'drop improvements
  * Fixed Last.fm authentication
  * Several fixed issues
* Thu May 26 2011 davejplater@gmail.com
- Added post and postun to update desktop database
* Wed May 25 2011 davejplater@gmail.com
- Removed gnutls from BuildRequires due to gloox license problems.
  see bnc#695820
* Thu May 19 2011 davejplater@gmail.com
- Added man page and BuildRequires: hicolor-icon-theme to own the
  icon directories.
* Sat Apr  2 2011 fisiu@opensuse.org
- Update to 0.7.1, bugfix release.
- Added gnutls to BuildRequires.
* Tue Mar 29 2011 fisiu@opensuse.org
- Update to 0.7:
  + brand new edit tag dialog
  + support for MusicBrainz tagging
  + support for CUE sheets
* Sat Dec 11 2010 bitshuffler@opensuse.org
- Update to 0.6.
* Thu Nov 11 2010 bitshuffler@opensuse.org
- Enable MTP and iPod support.
* Sun Oct  3 2010 bitshuffler@opensuse.org
- Update to 0.5.3.
* Sat Sep 25 2010 bitshuffler@opensuse.org
- Update to 0.5.1.
* Mon Sep 20 2010 bitshuffler@opensuse.org
- Update to 0.5.
* Sat Jul 10 2010 bitshuffler@opensuse.org
- Update to 0.4.2.
* Tue May 18 2010 bitshuffler@opensuse.org
- Updated to 0.3.
* Fri Mar 26 2010 bitshuffler@opensuse.org
- Updated to 0.2.
* Mon Mar  1 2010 bitshuffler@opensuse.org
- Initial package.
